@@ -12,7 +12,7 @@
 """
 
 import os
-from typing import List
+from typing import List, Optional
 
 from bs4 import BeautifulSoup
 from sphinx.application import Sphinx
@@ -29,9 +29,6 @@ def _get_html_files(outdir: str) -> List[str]:
         html_list.extend(
             [os.path.join(root, file) for file in files if file.endswith(".html")]
         )
-        #  for file in files:
-        #  if file.endswith(".html"):
-        #  html_list.append(os.path.join(root, file))
     return html_list
 
 
@@ -75,17 +72,27 @@ def _add_copy_button(tree: BeautifulSoup) -> None:
 
 
 def _collapsible_nav(tree: BeautifulSoup) -> None:
-    """Add small triangle icons to the links in the navigation.
+    """Restructure the navigation links to make them collapsible.
 
-    Adding them as spans instead of ``:after`` allows to capture
-    click events on the link and the expand icon separately.
+    First, all links in the navigation sidebar are wrapped in a ``div``.
+    This allows them to be 'block' and 'position relative' for the
+    'expand' icon to be positioned against. (Styling occurs in the CSS)
+    Note: We don't use tailwind classes here, as this is out of reach
+    for the PurgeCSS plugin.
+
+    Second, a span with the icon is inserted right before the link.
+    Adding the icon as separate DOM element allows click events to be
+    captured separately between the icon and the link.
     """
-    for link in tree.select("nav ul a"):
-        # ignore 'leaf' nodes
-        if link.next_sibling:
+    for link in tree.select("#nav-toc a"):
+        # First, all links should be wrapped in a div.nav-link
+        link.wrap(tree.new_tag("div", attrs={"class": "nav-link"}))
+        # Next, insert a span.expand before the link, if the #nav-link
+        # has any sibling elements (a ``ul`` in the navigation menu)
+        if link.parent.next_sibling:
             span = tree.new_tag("span", attrs={"class": "expand"})
-            span.string = "\u25be"
-            link.insert_after(span)
+            span.string = "\u203a"
+            link.insert_before(span)
 
 
 def _divs_to_section(tree: BeautifulSoup) -> None:
@@ -156,12 +163,30 @@ def _remove_pre_spans(tree: BeautifulSoup) -> None:
             span.unwrap()
 
 
+def _remove_xref_spans(tree: BeautifulSoup) -> None:
+    """Remove unnecessarily nested ``span.std-ref`` elements in cross-references."""
+    for link in tree("a"):
+        for span in link("span", class_="std-ref"):
+            span.unwrap()
+
+
 def _modify_html(html_filename: str) -> None:
     """Modify a single HTML document.
 
-    - Parse the HTML document into a tree
-    - Perform the modifications on the tree in place
-    - Write out the tree as new HTML document (with the same filename)
+    The HTML document is parsed into a BeautifulSoup tree.
+    Then, the following operations are performed on the tree.
+
+    - divs to sections
+    - divs to figures
+    - expand current
+    - collapsible navs
+    - wrap literal blocks
+    - add copy button
+    - add focus to headings
+    - remove pre spans
+
+    After these modifications, the HTML is written into a file,
+    overwriting the original file.
     """
     with open(html_filename) as html:
         tree = BeautifulSoup(html, "html.parser")
@@ -174,13 +199,22 @@ def _modify_html(html_filename: str) -> None:
     _add_copy_button(tree)
     _add_focus_to_headings(tree)
     _remove_pre_spans(tree)
+    _remove_xref_spans(tree)
 
     with open(html_filename, "w") as out_file:
         out_file.write(str(tree))
 
 
-def post_process_html(app: Sphinx, exc: Exception) -> None:
-    """Perform modifications on the built HTML."""
+def post_process_html(app: Sphinx, exc: Optional[Exception]) -> None:
+    """Perform modifications on the HTML after building.
+
+    This is an extra function, that gets a list from all HTML
+    files in the output directory, then runs the ``_modify_html``
+    function on each of them.
+    """
+    if app.builder.name not in ["html", "dirhtml"]:
+        return
+
     if exc is None:
         html_files = _get_html_files(app.outdir)
 
